==> xreview_0.96.zip: xreview/review.php <==
<?php
// =======================================
// xoops module xreview
// review.php
// =======================================
require('../../mainfile.php');
include_once XOOPS_ROOT_PATH.'/class/xoopsblock.php';
include_once 'class/xreview.php';
include_once 'class/xreview_data.php';

global $xoopsUser;
global $xoopsModule;
global $xoopsDB;
global $xoopsTpl;
global $xoopsConfig;

include_once XOOPS_ROOT_PATH."/modules/xreview/language/".$xoopsConfig['language']."/main.php";

//--------------
// 
//--------------
$myts =& MyTextSanitizer::getInstance();

//------------------------------------------------------
// ¥å
// access_typeͽ
//------------------------------------------------------
$edit_auth = 0;
if($xoopsUser != NULL) {
	$sql = "select group_id,access_type  from ".$xoopsDB->prefix( 'xreview_auth' );
	$res = $xoopsDB->query($sql);
	while($row = $xoopsDB->fetchArray($res)) {
		foreach($xoopsUser->_groups	 as $user_group_id) {
			if ( ($user_group_id == $row['group_id']) && (($row['access_type'] == "regist")) ) {
					$edit_auth = 1;
			}
		}
	}
}

//--------------------------
// ȤʤURI
//--------------------------
$target_uri = generateURIkey(XOOPS_URL,$_SERVER['REQUEST_URI']);

//--------------------------
// USERID 
//--------------------------
$userid = "";
if($edit_auth == 1) {
	$userid = $xoopsUser->getVar("uid");
}

//--------------------------------------------
// ɾƼ
// ڥ졼==ɾԤξӳ
//--------------------------------------------
$sql  = "select * from ".$xoopsDB->prefix( 'xreview_data' );
if( $edit_auth==1 ) {
	$sql .= " where user_id <> ".intval($userid)." AND request_uri = ".$xoopsDB->quoteString($target_uri);
} else {
	$sql .= " where request_uri = ".$xoopsDB->quoteString($target_uri);
}
$res = $xoopsDB->query($sql);
$item = array();
while($row = $xoopsDB->fetchArray($res))
{
	//------------------
	// ɾ
	//------------------
	//assign
	$reviewer_user_id = $row['user_id'];
	$point = intval($row['point']);
	$item['user_id'] = $myts->htmlSpecialChars( $reviewer_user_id );
	$item['id'] = $myts->htmlSpecialChars( $row['id'] );
	$item['comment'] = $myts->htmlSpecialChars( $row['comment'] );
	$item['point']   = $myts->htmlSpecialChars( $point );

	//------------------
	// ɾԤξ
	//------------------
	$reviewer = new XreviewerOperator($reviewer_user_id);
	$item['user_name'] = $myts->htmlSpecialChars( $reviewer->uname );
	$item['user_image'] = $myts->htmlSpecialChars( $reviewer->user_avatar );

	$xoopsTpl->append("mb", $item);
}

//---------------------------------------
//ڥ졼==ɾԤξ(Խ)
//---------------------------------------
if( ($edit_auth==1) ) {
	// ɾ
	$sql  = "select * from ".$xoopsDB->prefix( 'xreview_data' );
	$sql .= " where user_id = ".intval($userid)." AND request_uri = ".$xoopsDB->quoteString($target_uri);
	$res = $xoopsDB->query($sql);
	if ($row = $xoopsDB->fetchArray($res)){
		$myPoint = intval($row['point']);
		$xoopsTpl->assign("myComment", $myts->htmlSpecialChars( $row['comment'] ));
		$xoopsTpl->assign("myPoint", $myts->htmlSpecialChars( $myPoint ) );
		$xoopsTpl->assign("myPoint".$myPoint, "selected" );
		$xoopsTpl->assign("display_sw",1);
		//ͽ
		$xoopsTpl->assign("myTitle", $myts->htmlSpecialChars( $xoopsModule->getVar('name') ) );
	} else {
		//
		$xoopsTpl->assign("myComment", "" );
		$xoopsTpl->assign("myPoint", $myts->htmlSpecialChars( "brank" ) );
		$xoopsTpl->assign("myTitle", $myts->htmlSpecialChars( $xoopsModule->getVar('name') ) );
	}

	// ɾԤξ
	$reviewer = new XreviewerOperator($userid);
	$xoopsTpl->assign("myName", $myts->htmlSpecialChars( $reviewer->uname ));
	$xoopsTpl->assign("myImage", $myts->htmlSpecialChars( $reviewer->user_avatar ));
}

//----------
// Խ
//----------
$xoopsTpl->assign("edit_sw",$edit_auth);

//----------------
// 
//----------------
$xoopsTpl->assign("review_form_subject", _MB_LABEL_REVIEW_FORM_SUBJECT );
$xoopsTpl->assign("review_form_comment", _MB_LABEL_REVIEW_FORM_COMMENT );
$xoopsTpl->assign("review_form_point", _MB_LABEL_REVIEW_FORM_POINT );
$xoopsTpl->assign("review_form_point_note", _MB_LABEL_REVIEW_FORM_POINT_NOTE );
$xoopsTpl->assign("review_form_edit", _MB_LABEL_REVIEW_FORM_EDIT );
$xoopsTpl->assign("review_form_add", _MB_LABEL_REVIEW_FORM_ADD );
$xoopsTpl->assign("review_form_cancel", _MB_LABEL_REVIEW_FORM_CANCEL );
$xoopsTpl->display("db:xreview_block.html");

?>

==> xreview_0.97.zip: xreview/review.php <==
<?php
// =======================================
// xoops module xreview
// review.php
// =======================================
require('../../mainfile.php');
include_once XOOPS_ROOT_PATH.'/class/xoopsblock.php';
include_once 'class/xreview.php';
include_once 'class/xreview_data.php';

global $xoopsUser;
global $xoopsModule;
global $xoopsDB;
global $xoopsTpl;
global $xoopsConfig;

include_once XOOPS_ROOT_PATH."/modules/xreview/language/".$xoopsConfig['language']."/main.php";

//--------------
// 
//--------------
$myts =& MyTextSanitizer::getInstance();

//------------------------------------------------------
// ¥å
// access_typeͽ
//------------------------------------------------------
$edit_auth = 0;
if($xoopsUser != NULL) {
	$sql = "select group_id,access_type  from ".$xoopsDB->prefix( 'xreview_auth' );
	$res = $xoopsDB->query($sql);
	while($row = $xoopsDB->fetchArray($res)) {
		foreach($xoopsUser->_groups	 as $user_group_id) {
			if ( ($user_group_id == $row['group_id']) && (($row['access_type'] == "regist")) ) {
					$edit_auth = 1;
			}
		}
	}
}

//--------------------------
// ȤʤURI
//--------------------------
$target_uri = generateURIkey(XOOPS_URL,$_SERVER['REQUEST_URI']);

//--------------------------
// USERID 
//--------------------------
$userid = "";
if($edit_auth == 1) {
	$userid = $xoopsUser->getVar("uid");
}

//--------------------------------------------
// ɾƼ
// ڥ졼==ɾԤξӳ
//--------------------------------------------
$sql  = "select * from ".$xoopsDB->prefix( 'xreview_data' );
if( $edit_auth==1 ) {
	$sql .= " where user_id <> ".intval($userid)." AND request_uri = ".$xoopsDB->quoteString($target_uri);
} else {
	$sql .= " where request_uri = ".$xoopsDB->quoteString($target_uri);
}
$res = $xoopsDB->query($sql);
$item = array();
while($row = $xoopsDB->fetchArray($res))
{
	//------------------
	// ɾ
	//------------------
	//assign
	$reviewer_user_id = $row['user_id'];
	$point = intval($row['point']);
	$item['user_id'] = $myts->htmlSpecialChars( $reviewer_user_id );
	$item['id'] = $myts->htmlSpecialChars( $row['id'] );
	$comment = $myts->htmlSpecialChars( $row['comment'] );
	$comment = str_replace("\n","<br>\n",$comment);
	$item['comment'] = $comment;

	$item['point']   = $myts->htmlSpecialChars( $point );

	//------------------
	// ɾԤξ
	//------------------
	$reviewer = new XreviewerOperator($reviewer_user_id);
	$item['user_name'] = $myts->htmlSpecialChars( $reviewer->uname );
	$item['user_image'] = $myts->htmlSpecialChars( $reviewer->user_avatar );

	$xoopsTpl->append("mb", $item);
}

//---------------------------------------
//ڥ졼==ɾԤξ(Խ)
//---------------------------------------
if( ($edit_auth==1) ) {
	// ɾ
	$sql  = "select * from ".$xoopsDB->prefix( 'xreview_data' );
	$sql .= " where user_id = ".intval($userid)." AND request_uri = ".$xoopsDB->quoteString($target_uri);
	$res = $xoopsDB->query($sql);
	if ($row = $xoopsDB->fetchArray($res)){
		$myPoint = intval($row['point']);

		$myComment = $myts->htmlSpecialChars( $row['comment'] );

		$myComment_view = str_replace("\n","<br>\n",$myComment);
		$item['comment'] = $comment;
		$xoopsTpl->assign("myComment_view", $myComment_view);

		$xoopsTpl->assign("myComment", $myComment);
		$xoopsTpl->assign("myPoint", $myts->htmlSpecialChars( $myPoint ) );
		$xoopsTpl->assign("myPoint".$myPoint, "selected" );
		$xoopsTpl->assign("display_sw",1);
		//ͽ
		$xoopsTpl->assign("myTitle", $myts->htmlSpecialChars( $xoopsModule->getVar('name') ) );
	} else {
		//
		$xoopsTpl->assign("myComment", "" );
		$xoopsTpl->assign("myPoint", $myts->htmlSpecialChars( "brank" ) );
		$xoopsTpl->assign("myTitle", $myts->htmlSpecialChars( $xoopsModule->getVar('name') ) );
	}

	// ɾԤξ
	$reviewer = new XreviewerOperator($userid);
	$xoopsTpl->assign("myName", $myts->htmlSpecialChars( $reviewer->uname ));
	$xoopsTpl->assign("myImage", $myts->htmlSpecialChars( $reviewer->user_avatar ));
}

//åȺ
$ticket = sha1(array_sum(explode(" ", microtime())));
$_SESSION['ticket'] = $ticket;

//åȾ
$token  = sha1("xreview".$ticket);
$_SESSION[$ticket] = $token;
$xoopsTpl->assign("token", $token );

//target_uri
$_SESSION['target_uri'] = $target_uri;

//----------
// Խ
//----------
$xoopsTpl->assign("edit_sw",$edit_auth);

//----------------
// 
//----------------
$xoopsTpl->assign("review_form_subject", _MB_LABEL_REVIEW_FORM_SUBJECT );
$xoopsTpl->assign("review_form_comment", _MB_LABEL_REVIEW_FORM_COMMENT );
$xoopsTpl->assign("review_form_point", _MB_LABEL_REVIEW_FORM_POINT );
$xoopsTpl->assign("review_form_point_note", _MB_LABEL_REVIEW_FORM_POINT_NOTE );
$xoopsTpl->assign("review_form_edit", _MB_LABEL_REVIEW_FORM_EDIT );
$xoopsTpl->assign("review_form_add", _MB_LABEL_REVIEW_FORM_ADD );
$xoopsTpl->assign("review_form_cancel", _MB_LABEL_REVIEW_FORM_CANCEL );
$xoopsTpl->display("db:xreview_block.html");

?>
